<?php
/**
 * Mega Construction functions and definitions
 * @package Mega Construction
 */

/* Breadcrumb Begin */
function mega_construction_the_breadcrumb() {
	if (!is_home()) {
		echo '<a href="';
			echo esc_url( home_url() );
		echo '">';
			bloginfo('name');
		echo "</a> ";
		if (is_category() || is_single()) {
			the_category(',');
			if (is_single()) {
				echo "<span> ";
					the_title();
				echo "</span> ";
			}
		} elseif (is_page()) {
			the_title();
		}
	}
}


/* Theme Setup */
if ( ! function_exists( 'mega_construction_setup' ) ) :

function mega_construction_setup() {

	$GLOBALS['content_width'] = apply_filters( 'mega_construction_content_width', 640 );
	
	load_theme_textdomain( 'mega-construction', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('mega-construction-homepage-thumb',240,145,true);
	
    register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'mega-construction' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', mega_construction_font_url() ) );

	// Theme Activation Notice
	global $pagenow;
	
	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'mega_construction_activation_notice' );
	}
}
endif;
add_action( 'after_setup_theme', 'mega_construction_setup' );

// Notice after Theme Activation
function mega_construction_activation_notice() {
	echo '<div class="notice notice-success is-dismissible welcome">';
		echo '<h3>'. esc_html__( 'Greetings from Themeglance!!', 'mega-construction' ) .'</h3>';
		echo '<p>'. esc_html__( 'A heartful thank you for choosing Themeglance. We promise to deliver only the best to you. Please proceed towards welcome section to get started.', 'mega-construction' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=mega_construction_guide' ) ) .'" class="button button-primary">'. esc_html__( 'About Theme', 'mega-construction' ) .'</a></p>';
	echo '</div>';
}


/* Theme Widgets Setup */
function mega_construction_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'mega-construction' ),
		'description'   => __( 'Appears on blog page sidebar', 'mega-construction' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'mega-construction' ),
		'description'   => __( 'Appears on page sidebar', 'mega-construction' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Column Sidebar', 'mega-construction' ),
		'description'   => __( 'Appears on page sidebar', 'mega-construction' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'mega-construction' ),
		'description'   => __( 'Appears on footer', 'mega-construction' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'mega-construction' ),
		'description'   => __( 'Appears on footer', 'mega-construction' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'mega-construction' ),
		'description'   => __( 'Appears on footer', 'mega-construction' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'mega-construction' ),
		'description'   => __( 'Appears on footer', 'mega-construction' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'mega_construction_widgets_init' );

/* Theme Font URL */
function mega_construction_font_url() {
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Montserrat:300,400,600,700,800,900';
	$font_family[] = 'Roboto:400,700';
	$font_family[] = 'Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';

	$query_args = array(
		'family'	=> urlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}

/*radio button sanitization*/
 function mega_construction_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Theme enqueue scripts */
function mega_construction_scripts() {
	wp_enqueue_style( 'mega-construction-font', mega_construction_font_url(), array() );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'mega-construction-basic-style', get_stylesheet_uri() );
	wp_style_add_data( 'mega-construction-style', 'rtl', 'replace' );
	wp_enqueue_style( 'mega-construction-effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_style( 'css-nivo-slider', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'jquery-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'bootstrap-scripts', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_style('mega-construction-ie', get_template_directory_uri().'/css/ie.css', array('mega-construction-basic-style'));
	wp_style_add_data( 'mega-construction-ie', 'conditional', 'IE' );
}
add_action( 'wp_enqueue_scripts', 'mega_construction_scripts' );

/* Theme Credit link */

define('MEGA_CONSTRUCTION_PRO_THEME_URL','https://www.themesglance.com/themes/premium-construction-wordpress-theme/','the-wp-fitness');
define('MEGA_CONSTRUCTION_THEME_DOC','http://www.themesglance.com/docs/mega-construction-pro/','the-wp-fitness');
define('MEGA_CONSTRUCTION_LIVE_DEMO','https://themesglance.com/mega-construction-pro/','the-wp-fitness');
define('MEGA_CONSTRUCTION_FREE_THEME_DOC','http://themesglance.com/docs/free-mega-construction/','the-wp-fitness');
define('MEGA_CONSTRUCTION_SUPPORT','https://wordpress.org/support/theme/mega-construction/','the-wp-fitness');
define('MEGA_CONSTRUCTION_REVIEW','https://www.themesglance.com/support/?view=forum&id=5','the-wp-fitness');

define('MEGA_CONSTRUCTION_SITE_URL','https://www.themesglance.com/');

function mega_construction_credit_link() {
    echo "<a href=".esc_url(MEGA_CONSTRUCTION_SITE_URL)." target='_blank'>".esc_html__('ThemesGlance','mega-construction')."</a>";
}

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Implement the About theme */
require get_template_directory() . '/inc/getting-started/getting-started.php';