<?php
/**
 * Mega Construction Theme Customizer
 * @package Mega Construction
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function mega_construction_customize_register( $wp_customize ) {	

	//add home page setting pannel
	$wp_customize->add_panel( 'mega_construction_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'TG Settings', 'mega-construction' ),
	    'description' => __( 'Description of what this panel does.', 'mega-construction' ),
	) );

	//layout setting
	$wp_customize->add_section( 'mega_construction_theme_layout', array(
    	'title'      => __( 'Layout Settings', 'mega-construction' ),
		'priority'   => 30,
		'panel' => 'mega_construction_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('mega_construction_layout',array(
	        'default' => __( 'Right Sidebar', 'mega-construction' ),
	        'sanitize_callback' => 'mega_construction_sanitize_choices'	        
	    )
    );

	$wp_customize->add_control('mega_construction_layout',
	    array(
	        'type' => 'radio',
	        'label' => __( 'Do you want this section', 'mega-construction' ),
	        'section' => 'mega_construction_theme_layout',
	        'choices' => array(
	            'Left Sidebar' => __('Left Sidebar','mega-construction'),
	            'Right Sidebar' => __('Right Sidebar','mega-construction'),
	            'One Column' => __('One Column','mega-construction'),
	            'Three Columns' => __('Three Columns','mega-construction'),
	            'Four Columns' => __('Four Columns','mega-construction'),
	            'Grid Layout' => __('Grid Layout','mega-construction')
	        ),
	    )
    );

	//Topbar section
	$wp_customize->add_section('mega_construction_topbar_icon',array(
		'title'	=> __('Topbar Section','mega-construction'),
		'description'	=> __('Add Header Content here','mega-construction'),
		'priority'	=> null,
		'panel' => 'mega_construction_panel_id',
	));

	$wp_customize->add_setting('mega_construction_address',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('mega_construction_address',array(
		'label'	=> __('Add Address','mega-construction'),
		'section'	=> 'mega_construction_topbar_icon',
		'setting'	=> 'mega_construction_address',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('mega_construction_phone',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('mega_construction_phone',array(
		'label'	=> __('Add Contact','mega-construction'),
		'section'	=> 'mega_construction_topbar_icon',
		'setting'	=> 'mega_construction_phone',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('mega_construction_phone1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('mega_construction_phone1',array(
		'label'	=> __('Add Contact','mega-construction'),
		'section'	=> 'mega_construction_topbar_icon',
		'setting'	=> 'mega_construction_phone1',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('mega_construction_email',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('mega_construction_email',array(
		'label'	=> __('Add Email','mega-construction'),
		'section'	=> 'mega_construction_topbar_icon',
		'setting'	=> 'mega_construction_email',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('mega_construction_email1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('mega_construction_email1',array(
		'label'	=> __('Add Email','mega-construction'),
		'section'	=> 'mega_construction_topbar_icon',
		'setting'	=> 'mega_construction_email1',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('mega_construction_button_link',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	
	$wp_customize->add_control('mega_construction_button_link',array(
		'label'	=> __('Contact us url','mega-construction'),
		'section'	=> 'mega_construction_topbar_icon',
		'setting'	=> 'mega_construction_button_link',
		'type'		=> 'url'
	));
	

	//home page slider
	$wp_customize->add_section( 'mega_construction_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'mega-construction' ),
		'priority'   => 30,
		'panel' => 'mega_construction_panel_id'
	) );

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'mega_construction_slidersettings-page-' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'absint'
		) );

		$wp_customize->add_control( 'mega_construction_slidersettings-page-' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'mega-construction' ),
			'section'  => 'mega_construction_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}
	
	//About
	$wp_customize->add_section('mega_construction_about1',array(
		'title'	=> __('About Section','mega-construction'),
		'description'	=> __('Add About sections below.','mega-construction'),
		'panel' => 'mega_construction_panel_id',
	));

	$post_list = get_posts();
	$i = 0;
	foreach($post_list as $post){
		$posts[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('mega_construction_about_setting',array(
		'sanitize_callback' => 'mega_construction_sanitize_choices',
	));

	$wp_customize->add_control('mega_construction_about_setting',array(
		'type'    => 'select',
		'choices' => $posts,
		'label' => __('Select post','mega-construction'),
		'section' => 'mega_construction_about1',
	));

	//footer text
	$wp_customize->add_section('mega_construction_footer_section',array(
		'title'	=> __('Footer Text','mega-construction'),
		'description'	=> __('Add some text for footer like copyright etc.','mega-construction'),
		'panel' => 'mega_construction_panel_id'
	));
	
	$wp_customize->add_setting('mega_construction_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('mega_construction_text',array(
		'label'	=> __('Copyright Text','mega-construction'),
		'section'	=> 'mega_construction_footer_section',
		'type'		=> 'text'
	));	
}
add_action( 'customize_register', 'mega_construction_customize_register' );	

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class mega_construction_customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Mega_Construction_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Mega_Construction_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority'   => 9,
					'title'    => esc_html__( 'Mega Construction Pro', 'mega-construction' ),
					'pro_text' => esc_html__( 'Go Pro', 'mega-construction' ),
					'pro_url'  => esc_url('https://www.themesglance.com/themes/premium-construction-wordpress-theme/'	),				
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'mega-construction-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'mega-construction-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
mega_construction_customize::get_instance();